@@ -144,16 +144,6 @@ sexp_itemsize(SEXP sexp)
 /* } */
 
 
-#if (PY_VERSION_HEX < 0x02070000)  
-static void
-array_struct_free(void *ptr, void *arr)
-{
-  PyArrayInterface *inter       = (PyArrayInterface *)ptr;
-  PyMem_Free(inter->shape);
-  Py_DECREF((PyObject *)arr);
-  PyMem_Free(inter);
-}
-#else
 static void
 array_struct_free(PyObject *rpynumpycapsule)
 {
@@ -163,7 +153,6 @@ array_struct_free(PyObject *rpynumpycapsule)
   PyMem_Free(inter->shape);
   PyMem_Free(inter);
 }
-#endif
 
 static PyObject* 
 array_struct_get(PySexpObject *self)
@@ -210,12 +199,8 @@ array_struct_get(PySexpObject *self)
     return NULL;
   }
   Py_INCREF(self);
-#if (PY_VERSION_HEX < 0x02070000) 
-  return PyCObject_FromVoidPtrAndDesc(inter, self, array_struct_free);
-#else
   return PyCapsule_New(inter,
 		       NULL, /* Numpy does not seem to give a name */
 		       (PyCapsule_Destructor) array_struct_free);
-#endif
 }
 
