@@ -42,11 +42,7 @@ NAInteger_repr(PyObject *self)
 {
   static PyObject* repr = NULL;
   if (repr == NULL) {
-#if (PY_VERSION_HEX < 0x03010000)  
-    repr = PyString_FromString("NA_integer_");
-#else
     repr = PyUnicode_FromString("NA_integer_");
-#endif
   }
   Py_XINCREF(repr);
   return repr;
@@ -57,11 +53,7 @@ NA_str(PyObject *self)
 {
   static PyObject* repr = NULL;
   if (repr == NULL) {
-#if (PY_VERSION_HEX < 0x03010000)  
-    repr = PyString_FromString("NA");
-#else
     repr = PyUnicode_FromString("NA");
-#endif
   }
   Py_XINCREF(repr);
   return repr;
@@ -100,9 +92,6 @@ static PyNumberMethods NAInteger_NumberMethods = {
   (binaryfunc)NA_binaryfunc, /* nb_add */
   (binaryfunc)NA_binaryfunc, /* nb_subtract; */
   (binaryfunc)NA_binaryfunc, /* nb_multiply; */
-#if (PY_VERSION_HEX < 0x03010000)
-  (binaryfunc)NA_binaryfunc, /* nb_divide; */
-#endif
   (binaryfunc)NA_binaryfunc, /* nb_remainder; */
   (binaryfunc)NA_binaryfunc, /* nb_divmod; */
   (ternaryfunc)NA_ternaryfunc, /* nb_power; */
@@ -116,27 +105,13 @@ static PyNumberMethods NAInteger_NumberMethods = {
   (binaryfunc) NA_binaryfunc, /*  nb_and; */
   (binaryfunc) NA_binaryfunc, /*  nb_xor; */
   (binaryfunc) NA_binaryfunc, /* nb_or; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, //(coerce) NA_coerce, /* coercion nb_coerce;       -- Used by the coerce() function */
-#endif
   (unaryfunc) NA_unaryfunc, /* nb_int; */
-#if (PY_VERSION_HEX < 0x03010000)
-  (unaryfunc) NA_unaryfunc, /* nb_long; */
-#else
   NULL, /* reserved */
-#endif
   (unaryfunc) NA_unaryfunc, /* nb_float; */
-#if (PY_VERSION_HEX < 0x03010000)
-  (unaryfunc) NA_unaryfunc, /* nb_oct; */
-  (unaryfunc) NA_unaryfunc, /* nb_hex; */
-#endif
   /* Added in release 2.0 */
   (binaryfunc)NA_binaryfunc, /* nb_inplace_add; */
   (binaryfunc)NA_binaryfunc, /* nb_inplace_subtract; */
   (binaryfunc)NA_binaryfunc, /* nb_inplace_multiply; */
-#if (PY_VERSION_HEX < 0x03010000)
-  (binaryfunc)NA_binaryfunc, /* nb_inplace_divide; */
-#endif
   (binaryfunc)NA_binaryfunc, /* nb_inplace_remainder; */
   (ternaryfunc)NA_ternaryfunc, /* nb_inplace_power; */
   0, /* nb_inplace_lshift; */
@@ -149,10 +124,7 @@ static PyNumberMethods NAInteger_NumberMethods = {
   (binaryfunc) NA_binaryfunc, /* nb_true_divide; */
   (binaryfunc)NA_binaryfunc, /* nb_inplace_floor_divide; */
   (binaryfunc)NA_binaryfunc, /* nb_inplace_true_divide; */
-  /* Added in release 2.5 */
-#if PY_VERSION_HEX >= 0x02050000
   (unaryfunc) NA_unaryfunc /* nb_index; */
-#endif
 };
 
 
@@ -163,12 +135,7 @@ NAInteger_tp_new(PyTypeObject *type, PyObject *args, PyObject *kwds);
 static PyTypeObject NAInteger_Type = {
         /* The ob_type field must be initialized in the module init function
          * to be portable to Windows without using C++. */
-#if (PY_VERSION_HEX < 0x03010000)
-        PyObject_HEAD_INIT(NULL)
-        0,                      /*ob_size*/
-#else
 	PyVarObject_HEAD_INIT(NULL, 0)
-#endif
         "rpy2.rinterface.NAIntegerType",       /*tp_name*/
         sizeof(PyLongObject),   /*tp_basicsize*/
         0,                      /*tp_itemsize*/
@@ -188,11 +155,7 @@ static PyTypeObject NAInteger_Type = {
         0,                      /*tp_getattro*/
         0,                      /*tp_setattro*/
         0,                      /*tp_as_buffer*/
-#if (PY_VERSION_HEX < 0x03010000)
-        Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
-#else
         Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE, /*tp_flags*/
-#endif
         NAInteger_Type_doc,                      /*tp_doc*/
         0,                      /*tp_traverse*/
         0,                      /*tp_clear*/
@@ -289,11 +252,7 @@ NALogical_repr(PyObject *self)
 {
   static PyObject* repr = NULL;
   if (repr == NULL) {
-#if (PY_VERSION_HEX < 0x03010000)  
-    repr = PyString_FromString("NA");
-#else
     repr = PyUnicode_FromString("NA");
-#endif
   }
   Py_XINCREF(repr);
   return repr;
@@ -303,9 +262,6 @@ static PyNumberMethods NALogical_NumberMethods = {
   0, /* nb_add */
   0, /* nb_subtract; */
   0, /* nb_multiply; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, /* nb_divide; */
-#endif
   0, /* nb_remainder; */
   0, /* nb_divmod; */
   0, /* nb_power; */
@@ -319,27 +275,13 @@ static PyNumberMethods NALogical_NumberMethods = {
   (binaryfunc) NA_binaryfunc, /*  nb_and; */
   (binaryfunc) NA_binaryfunc, /*  nb_xor; */
   (binaryfunc) NA_binaryfunc, /* nb_or; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, //(coerce) NA_coerce, /* coercion nb_coerce;       -- Used by the coerce() function */
-#endif
   0, /* nb_int; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, /* nb_long; */
-#else
   NULL, /* reserved */
-#endif
   0, /* nb_float; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, /* nb_oct; */
-  0, /* nb_hex; */
-#endif
   /* Added in release 2.0 */
   0, /* nb_inplace_add; */
   0, /* nb_inplace_subtract; */
   0, /* nb_inplace_multiply; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, /* nb_inplace_divide; */
-#endif
   0, /* nb_inplace_remainder; */
   0, /* nb_inplace_power; */
   0, /* nb_inplace_lshift; */
@@ -353,20 +295,13 @@ static PyNumberMethods NALogical_NumberMethods = {
   0, /* nb_inplace_floor_divide; */
   0, /* nb_inplace_true_divide; */
   /* Added in release 2.5 */
-#if PY_VERSION_HEX >= 0x02050000
   0 /* nb_index; */
-#endif
 };
 
 static PyTypeObject NALogical_Type = {
         /* The ob_type field must be initialized in the module init function
          * to be portable to Windows without using C++. */
-#if (PY_VERSION_HEX < 0x03010000)
-        PyObject_HEAD_INIT(NULL)
-        0,                      /*ob_size*/
-#else
 	PyVarObject_HEAD_INIT(NULL, 0)
-#endif
         "rpy2.rinterface.NALogicalType",       /*tp_name*/
         sizeof(PyLongObject),   /*tp_basicsize*/
         0,                      /*tp_itemsize*/
@@ -386,11 +321,7 @@ static PyTypeObject NALogical_Type = {
         0,                      /*tp_getattro*/
         0,                      /*tp_setattro*/
         0,                      /*tp_as_buffer*/
-#if (PY_VERSION_HEX < 0x03010000)
-        Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
-#else
         Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE, /*tp_flags*/
-#endif
         NALogical_Type_doc,                      /*tp_doc*/
         0,                      /*tp_traverse*/
         0,                      /*tp_clear*/
@@ -473,11 +404,7 @@ NAReal_repr(PyObject *self)
 {
   static PyObject* repr = NULL;
   if (repr == NULL) {
-#if (PY_VERSION_HEX < 0x03010000)  
-    repr = PyString_FromString("NA_real_");
-#else
     repr = PyUnicode_FromString("NA_real_");
-#endif
   }
   Py_XINCREF(repr);
   return repr;
@@ -488,9 +415,6 @@ static PyNumberMethods NAReal_NumberMethods = {
   (binaryfunc)NA_binaryfunc, /* nb_add */
   (binaryfunc)NA_binaryfunc, /* nb_subtract; */
   (binaryfunc)NA_binaryfunc, /* nb_multiply; */
-#if (PY_VERSION_HEX < 0x03010000)
-  (binaryfunc)NA_binaryfunc, /* nb_divide; */
-#endif
   (binaryfunc)NA_binaryfunc, /* nb_remainder; */
   (binaryfunc)NA_binaryfunc, /* nb_divmod; */
   (ternaryfunc)NA_ternaryfunc, /* nb_power; */
@@ -504,27 +428,13 @@ static PyNumberMethods NAReal_NumberMethods = {
   0, /*  nb_and; */
   0, /*  nb_xor; */
   0, /* nb_or; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, //(coerce) NA_coerce, /* coercion nb_coerce;       -- Used by the coerce() function */
-#endif
   (unaryfunc) NA_unaryfunc, /* nb_int; */
-#if (PY_VERSION_HEX < 0x03010000)
-  (unaryfunc) NA_unaryfunc, /* nb_long; */
-#else
   NULL, /* reserved */
-#endif
   (unaryfunc) NA_unaryfunc, /* nb_float; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, /* nb_oct; */
-  0, /* nb_hex; */
-#endif
   /* Added in release 2.0 */
   0, /* nb_inplace_add; */
   0, /* nb_inplace_subtract; */
   0, /* nb_inplace_multiply; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, /* nb_inplace_divide; */
-#endif
   0, /* nb_inplace_remainder; */
   0, /* nb_inplace_power; */
   0, /* nb_inplace_lshift; */
@@ -538,21 +448,14 @@ static PyNumberMethods NAReal_NumberMethods = {
   0, /* nb_inplace_floor_divide; */
   0, /* nb_inplace_true_divide; */
   /* Added in release 2.5 */
-#if PY_VERSION_HEX >= 0x02050000
   0 /* nb_index; */
-#endif
 };
 
 
 static PyTypeObject NAReal_Type = {
         /* The ob_type field must be initialized in the module init function
          * to be portable to Windows without using C++. */
-#if (PY_VERSION_HEX < 0x03010000)
-        PyObject_HEAD_INIT(NULL)
-        0,                      /*ob_size*/
-#else
 	PyVarObject_HEAD_INIT(NULL, 0)
-#endif
         "rpy2.rinterface.NARealType",       /*tp_name*/
         sizeof(PyFloatObject),   /*tp_basicsize*/
         0,                      /*tp_itemsize*/
@@ -572,11 +475,7 @@ static PyTypeObject NAReal_Type = {
         0,                      /*tp_getattro*/
         0,                      /*tp_setattro*/
         0,                      /*tp_as_buffer*/
-#if (PY_VERSION_HEX < 0x03010000)
-        Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
-#else
         Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE, /*tp_flags*/
-#endif
         NAReal_Type_doc,                      /*tp_doc*/
         0,                      /*tp_traverse*/
         0,                      /*tp_clear*/
@@ -612,11 +511,7 @@ PyDoc_STRVAR(NACharacter_Type_doc,
 static PyObject*
 NACharacter_tp_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
-#if (PY_VERSION_HEX < 0x03010000)
-  RPY_NA_TP_NEW("NACharacterType", PyString_Type, PyString_FromString, "")
-#else
     RPY_NA_TP_NEW("NACharacterType", PyUnicode_Type, PyUnicode_FromString, "")
-#endif
 }
 
 static PyObject*
@@ -631,11 +526,7 @@ NACharacter_repr(PyObject *self)
 {
   static PyObject* repr = NULL;
   if (repr == NULL) {
-#if (PY_VERSION_HEX < 0x03010000)
-    repr = PyString_FromString("NA_character_");
-#else
     repr = PyUnicode_FromString("NA_character_");
-#endif
   }
   Py_XINCREF(repr);
   return repr;
@@ -645,18 +536,9 @@ NACharacter_repr(PyObject *self)
 static PyTypeObject NACharacter_Type = {
         /* The ob_type field must be initialized in the module init function
          * to be portable to Windows without using C++. */
-#if (PY_VERSION_HEX < 0x03010000)
-        PyObject_HEAD_INIT(NULL)
-        0,                      /*ob_size*/
-#else
 	PyVarObject_HEAD_INIT(NULL, 0)
-#endif
         "rpy2.rinterface.NACharacterType",       /*tp_name*/
-#if (PY_VERSION_HEX < 0x03010000)
-        sizeof(PyStringObject),             /*tp_basicsize*/
-#else
 	sizeof(PyUnicodeObject),             /*tp_basicsize*/
-#endif
         0,                      /*tp_itemsize*/
         /* methods */
         0, /*tp_dealloc*/
@@ -674,11 +556,7 @@ static PyTypeObject NACharacter_Type = {
         0,                      /*tp_getattro*/
         0,                      /*tp_setattro*/
         0,                      /*tp_as_buffer*/
-#if (PY_VERSION_HEX < 0x03010000)
-        Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
-#else
         Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE, /*tp_flags*/
-#endif
         NACharacter_Type_doc,                      /*tp_doc*/
         0,                      /*tp_traverse*/
         0,                      /*tp_clear*/
@@ -691,8 +569,6 @@ static PyTypeObject NACharacter_Type = {
         0,                      /*tp_getset*/
 #if defined(Win32) || defined(Win64)
 	NULL,
-#elif (PY_VERSION_HEX < 0x03010000)
-        &PyString_Type,             /*tp_base*/
 #else
 	&PyUnicode_Type,
 #endif
@@ -742,11 +618,7 @@ NAComplex_repr(PyObject *self)
 {
   static PyObject* repr = NULL;
   if (repr == NULL) {
-#if (PY_VERSION_HEX < 0x03010000)
-    repr = PyString_FromString("NA_complex_");
-#else
     repr = PyUnicode_FromString("NA_complex_");
-#endif
   }
   Py_XINCREF(repr);
   return repr;
@@ -757,9 +629,6 @@ static PyNumberMethods NAComplex_NumberMethods = {
   (binaryfunc)NA_binaryfunc, /* nb_add */
   (binaryfunc)NA_binaryfunc, /* nb_subtract; */
   (binaryfunc)NA_binaryfunc, /* nb_multiply; */
-#if (PY_VERSION_HEX < 0x03010000)
-  (binaryfunc)NA_binaryfunc, /* nb_divide; */
-#endif
   (binaryfunc)NA_binaryfunc, /* nb_remainder; */
   (binaryfunc)NA_binaryfunc, /* nb_divmod; */
   (ternaryfunc)NA_ternaryfunc, /* nb_power; */
@@ -773,27 +642,13 @@ static PyNumberMethods NAComplex_NumberMethods = {
   0, /*  nb_and; */
   0, /*  nb_xor; */
   0, /* nb_or; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, //(coerce) NA_coerce, /* coercion nb_coerce;       -- Used by the coerce() function */
-#endif
   (unaryfunc) NA_unaryfunc, /* nb_int; */
-#if (PY_VERSION_HEX < 0x03010000)
-  (unaryfunc) NA_unaryfunc, /* nb_long; */
-#else
   NULL, /* reserved */
-#endif
   (unaryfunc) NA_unaryfunc, /* nb_float; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, /* nb_oct; */
-  0, /* nb_hex; */
-#endif
   /* Added in release 2.0 */
   0, /* nb_inplace_add; */
   0, /* nb_inplace_subtract; */
   0, /* nb_inplace_multiply; */
-#if (PY_VERSION_HEX < 0x03010000)
-  0, /* nb_inplace_divide; */
-#endif
   0, /* nb_inplace_remainder; */
   0, /* nb_inplace_power; */
   0, /* nb_inplace_lshift; */
@@ -807,21 +662,14 @@ static PyNumberMethods NAComplex_NumberMethods = {
   0, /* nb_inplace_floor_divide; */
   0, /* nb_inplace_true_divide; */
   /* Added in release 2.5 */
-#if PY_VERSION_HEX >= 0x02050000
   0 /* nb_index; */
-#endif
 };
 
 
 static PyTypeObject NAComplex_Type = {
         /* The ob_type field must be initialized in the module init function
          * to be portable to Windows without using C++. */
-#if (PY_VERSION_HEX < 0x03010000)
-        PyObject_HEAD_INIT(NULL)
-        0,                      /*ob_size*/
-#else
 	PyVarObject_HEAD_INIT(NULL, 0)
-#endif
         "rpy2.rinterface.NAComplexType",       /*tp_name*/
         sizeof(PyComplexObject),   /*tp_basicsize*/
         0,                      /*tp_itemsize*/
@@ -841,11 +689,7 @@ static PyTypeObject NAComplex_Type = {
         0,                      /*tp_getattro*/
         0,                      /*tp_setattro*/
         0,                      /*tp_as_buffer*/
-#if (PY_VERSION_HEX < 0x03010000)
-        Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
-#else
         Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE, /*tp_flags*/
-#endif
         NAComplex_Type_doc,                      /*tp_doc*/
         0,                      /*tp_traverse*/
         0,                      /*tp_clear*/
@@ -879,11 +723,7 @@ PyDoc_STRVAR(MissingArg_Type_doc,
 "Missing argument (in a function call)."
 );
 
-#if (PY_VERSION_HEX < 0x03010000)
-staticforward PyTypeObject MissingArg_Type;
-#else
 static PyTypeObject MissingArg_Type;
-#endif
 
 static PyObject*
 MissingArgType_tp_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
@@ -920,11 +760,7 @@ MissingArgType_repr(PyObject *self)
 {
   static PyObject* repr = NULL;
   if (repr == NULL) {
-#if (PY_VERSION_HEX < 0x03010000)
-    repr = PyString_FromString("rpy2.rinterface.MissingArg");
-#else
     repr = PyUnicode_FromString("rpy2.rinterface.MissingArg");
-#endif
   }
   Py_XINCREF(repr);
   return repr;
@@ -935,11 +771,7 @@ MissingArgType_str(PyObject *self)
 {
   static PyObject* repr = NULL;
   if (repr == NULL) {
-#if (PY_VERSION_HEX < 0x03010000)  
-    repr = PyString_FromString("MissingArg");
-#else
     repr = PyUnicode_FromString("MissingArg");
-#endif
   }
   Py_XINCREF(repr);
   return repr;
@@ -948,12 +780,7 @@ MissingArgType_str(PyObject *self)
 static PyTypeObject MissingArg_Type = {
         /* The ob_type field must be initialized in the module init function
          * to be portable to Windows without using C++. */
-#if (PY_VERSION_HEX < 0x03010000)
-        PyObject_HEAD_INIT(NULL)
-        0,                      /*ob_size*/
-#else
 	PyVarObject_HEAD_INIT(NULL, 0)
-#endif
         "rpy2.rinterface.MissingArgType",       /*tp_name*/
         sizeof(PySexpObject),   /*tp_basicsize*/
         0,                      /*tp_itemsize*/
@@ -973,11 +800,7 @@ static PyTypeObject MissingArg_Type = {
         0,                      /*tp_getattro*/
         0,                      /*tp_setattro*/
         0,                      /*tp_as_buffer*/
-#if (PY_VERSION_HEX < 0x03010000)
-        Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
-#else
         Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE, /*tp_flags*/
-#endif
         MissingArg_Type_doc,                      /*tp_doc*/
         0,                      /*tp_traverse*/
         0,                      /*tp_clear*/
