@@ -20,6 +20,7 @@
  * 
  * ***** END LICENSE BLOCK ***** */
 
+#include <stdlib.h>
 #include <Rdefines.h>
 #include <R_ext/Rallocators.h>
 #include "r_utils.h"
@@ -117,7 +118,7 @@ SEXP rpy2_unserialize(SEXP connection, SEXP rho)
   c_R = CDR(c_R);
   
   PROTECT(res = eval(call_R, rho));
-  UNPROTECT(2);
+  UNPROTECT(3);
   return res;
 }
 
