@@ -1,7 +1,13 @@
+import os
+import pytz
+from datetime import datetime
 import rpy2.robjects as ro
 import rpy2.robjects.conversion as conversion
 import rpy2.rinterface as rinterface
-from rpy2.rinterface import SexpVector, INTSXP
+from rpy2.rinterface import (SexpVector,
+                             StrSexpVector,
+                             IntSexpVector,
+                             INTSXP)
 
 from pandas.core.frame import DataFrame as PandasDataFrame
 from pandas.core.series import Series as PandasSeries
@@ -9,10 +15,13 @@ from pandas.core.index import Index as PandasIndex
 import pandas
 from numpy import recarray
 import numpy
+import warnings
 
 from collections import OrderedDict
 from rpy2.robjects.vectors import (DataFrame,
                                    Vector,
+                                   FactorVector,
+                                   FloatSexpVector,
                                    ListVector,
                                    StrVector,
                                    IntVector,
@@ -27,6 +36,7 @@ import rpy2.robjects.numpy2ri as numpy2ri
 
 
 ISOdatetime = rinterface.baseenv['ISOdatetime']
+as_vector = rinterface.baseenv['as.vector']
 
 converter = conversion.Converter('original pandas conversion')
 py2ri = converter.py2ri
@@ -34,17 +44,25 @@ py2ro = converter.py2ro
 ri2py = converter.ri2py
 ri2ro = converter.ri2ro
 
+# numpy types for Pandas columns that require (even more) special handling
+dt_datetime64ns_type = numpy.dtype('datetime64[ns]')
+dt_O_type = numpy.dtype('O')
+
 @py2ri.register(PandasDataFrame)
 def py2ri_pandasdataframe(obj):
     od = OrderedDict()
     for name, values in obj.iteritems():
-        if values.dtype.kind == 'O':
-            od[name] = StrVector(values)
-        else:
+        try:
             od[name] = conversion.py2ri(values)
+        except Exception as e:
+            warnings.warn('Error while trying to convert '
+                          'the column "%s". Fall back to string conversion. '
+                          'The error is: %s' %\
+                          (name, str(e)))
+            od[name] = StrVector(values)
+        
     return DataFrame(od)
 
-
 @py2ri.register(PandasIndex)
 def py2ri_pandasindex(obj):
     if obj.dtype.kind == 'O':
@@ -57,9 +75,28 @@ def py2ri_pandasindex(obj):
         # us to reuse that code.
         return numpy2ri.numpy2ri(obj)
 
+
+def py2ri_categoryseries(obj):
+    for c in obj.cat.categories:
+        if not isinstance(c, str):
+            raise ValueError('Converting pandas "Category" series to R factor is only possible when categories are strings.')
+    res = IntSexpVector(list(x+1 for x in obj.cat.codes))
+    res.do_slot_assign('levels', StrSexpVector(obj.cat.categories))
+    if obj.cat.ordered:
+        res.rclass = StrSexpVector(('ordered', 'factor'))
+    else:
+        res.rclass = StrSexpVector(('factor',))
+    return res
+
 @py2ri.register(PandasSeries)
 def py2ri_pandasseries(obj):
-    if obj.dtype == '<M8[ns]':
+    if numpy.dtype.name == 'O':
+        warnings.warn('Element "%s" is of dtype "O" and converted to R vector of strings.' % obj.name)
+        res = StrVector(obj)
+    elif obj.dtype.name == 'category':
+        res = py2ri_categoryseries(obj)
+        res = FactorVector(res)
+    elif obj.dtype == dt_datetime64ns_type:
         # time series
         d = [IntVector([x.year for x in obj]),
              IntVector([x.month for x in obj]),
@@ -73,12 +110,21 @@ def py2ri_pandasseries(obj):
         res = POSIXct(res)
     else:
         # converted as a numpy array
-        res = numpy2ri.numpy2ri(obj.values)
+        func = numpy2ri.converter.py2ri.registry[numpy.ndarray]
+        # current conversion as performed by numpy
+        res = func(obj)
+        if len(obj.shape) == 1:
+            if (obj.dtype != dt_O_type):
+                # force into an R vector
+                res=as_vector(res)
+
     # "index" is equivalent to "names" in R
     if obj.ndim == 1:
-        res.do_slot_assign('names', StrVector(tuple(str(x) for x in obj.index)))
+        res.do_slot_assign('names',
+                           StrVector(tuple(str(x) for x in obj.index)))
     else:
-        res.do_slot_assign('dimnames', SexpVector(conversion.py2ri(obj.index)))
+        res.do_slot_assign('dimnames',
+                           SexpVector(conversion.py2ri(obj.index)))
     return res
 
 @ri2py.register(SexpVector)
@@ -97,20 +143,57 @@ def ri2py_intvector(obj):
         res = numpy2ri.ri2py(obj)
     return res
 
+
+def get_timezone():
+    """ Return the system's timezone settings. """
+    etc_timezone = '/etc/timezone'
+    timezone = None
+    if os.path.exists(etc_timezone):
+        try:
+            with open(etc_timezone) as fh:
+                tz = fh.read().strip()
+            try :
+                timezone = pytz.timezone(tz)
+            except pytz.UnknownTimeZoneError:
+                warnings.warn('Unknown time zone in %s, using UTC.' % etc_timezone)
+                timezone = 'UTC'
+        except IOError:
+            warnings.warn('Unable to read date in %s, using UTC.' % etc_timezone)
+            timezone = 'UTC'
+    else:
+        warnings.warn('No file %s' % etc_timezone)
+    return timezone
+
+
+@ri2py.register(FloatSexpVector)
+def ri2py_floatvector(obj):
+    # special case for POSIXct date objects
+    if 'POSIXct' in obj.rclass:
+        tzone_name = obj.do_slot('tzone')[0]
+        if tzone_name == '':
+            # R is implicitly using the local timezone, while Python time libraries
+            # will assume UTC.
+            tzone = get_timezone()
+        else:
+            tzone = pytz.timezone(tzone_name)
+        foo = (tzone.localize(datetime.fromtimestamp(x)) for x in obj)
+        res = pandas.to_datetime(tuple(foo))
+    else:
+        res = numpy2ri.ri2py(obj)
+    return res
+
 @ri2py.register(ListSexpVector)
 def ri2py_listvector(obj):        
     if 'data.frame' in obj.rclass:
-        items = zip(obj.do_slot('names'), (numpy2ri.ri2py(x) for x in obj))
-        res = PandasDataFrame.from_items(items)
+        res = ri2py(DataFrame(obj))
     else:
         res = numpy2ri.ri2py(obj)
     return res
 
 @ri2py.register(DataFrame)
 def ri2py_dataframe(obj):
-    # use the numpy converter
-    recarray = numpy2ri.ri2py(obj)
-    res = PandasDataFrame.from_records(recarray)
+    items = tuple((k, ri2py(v)) for k, v in obj.items())
+    res = PandasDataFrame.from_items(items)
     return res
 
 def activate():
