@@ -27,7 +27,6 @@ class NumpyConversionsTestCase(unittest.TestCase):
 
     def testActivate(self):
         rpyn.deactivate()
-        robjects.conversion.py2ri = robjects.default_py2ri
         #FIXME: is the following still making sense ?
         self.assertNotEqual(rpyn.py2ri, conversion.py2ri)
         l = len(conversion.py2ri.registry)
@@ -40,7 +39,6 @@ class NumpyConversionsTestCase(unittest.TestCase):
 
     def testActivateTwice(self):
         rpyn.deactivate()
-        robjects.conversion.py2ri = robjects.default_py2ri
         #FIXME: is the following still making sense ?
         self.assertNotEqual(rpyn.py2ri, conversion.py2ri)
         l = len(conversion.py2ri.registry)
@@ -88,14 +86,6 @@ class NumpyConversionsTestCase(unittest.TestCase):
             self.assertTrue(abs(orig.real-conv.real) < 0.000001)
             self.assertTrue(abs(orig.imag-conv.imag) < 0.000001)
 
-    @unittest.skipUnless(sys.version_info[0] < 3,
-                         "Test only relevant if Python < 3.")
-    def testVectorCharacter(self):
-        l = ["a", "b", "c"]
-        s = numpy.array(l, dtype="S")
-        s_r = self.checkHomogeneous(s, "character", "character")
-        self.assertTupleEqual(tuple(l), tuple(s_r))
-
     def testVectorUnicodeCharacter(self):
         l = [u"a", u"b", u"c"]
         u = numpy.array(l, dtype="U")
@@ -132,6 +122,9 @@ class NumpyConversionsTestCase(unittest.TestCase):
         i64_test = numpy.array(i64_r)[0]
         self.assertEqual(i64, i64_test)
 
+    @unittest.skipUnless(has_numpy and hasattr(numpy, 'float128'),
+                         "numpy.float128 not available on this system")
+    def testScalar_f128(self):
         f128 = numpy.float128(100.000000003)
         f128_r = conversion.py2ri(f128)
         f128_test = numpy.array(f128_r)[0]
