@@ -5,6 +5,7 @@ import array
 import tempfile
 
 class RObjectTestCase(unittest.TestCase):
+    
     def testNew(self):
 
         identical = rinterface.baseenv["identical"]
@@ -47,6 +48,13 @@ class RObjectTestCase(unittest.TestCase):
                           x.rclass[0])
         self.assertEqual(old_class[0], x.rclass[1])
 
+    def testRclass_set_usingstring(self):
+        x = robjects.r("1:3")
+        old_class = x.rclass
+        x.rclass = "Foo"
+        self.assertEqual("Foo",
+                          x.rclass[0])
+        
     def testDo_slot(self):
         self.assertEqual("A1.4, p. 270",
                           robjects.globalenv.get("BOD").do_slot("reference")[0])
@@ -66,6 +74,7 @@ class RObjectTestCase(unittest.TestCase):
 import pickle
 
 class RObjectPicklingTestCase(unittest.TestCase):
+    
     def testPickle(self):
         tmp_file = tempfile.NamedTemporaryFile()
         robj = robjects.baseenv["pi"]
@@ -73,9 +82,17 @@ class RObjectPicklingTestCase(unittest.TestCase):
         tmp_file.flush()
         tmp_file.seek(0)
         robj_again = pickle.load(tmp_file)
+        tmp_file.close()
+
+        self.assertTrue(isinstance(robj, robjects.FloatVector))
+
+        # Check that underlying R objects are identical.
         self.assertTrue(robjects.baseenv["identical"](robj,
                                                       robj_again)[0])
-        tmp_file.close()
+        # Check the instance dict is also identical
+        self.assertSetEqual(set(robj.__dict__.keys()),
+                            set(robj_again.__dict__.keys())) 
+
 
 import rpy2.robjects.methods
 
